/*
 * Copyright (c) 2016, National Institute of Informatics
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.gakunin.idp.saml.xmlobject;

import java.util.List;

import javax.xml.namespace.QName;

import org.opensaml.saml.common.SAMLObject;

/**
 * uApproveJP Metadata RequestedAttributeExtension.
 */
public interface RequestedAttributeExtension extends SAMLObject {

    /** Local name of the Attribute element. */
    public static final String DEFAULT_ELEMENT_LOCAL_NAME = "RequestedAttributeExtension";

    /** Default element name. */
    public static final QName DEFAULT_ELEMENT_NAME = new QName(UApproveJPMetadata.NAMESPACE,
            DEFAULT_ELEMENT_LOCAL_NAME, UApproveJPMetadata.PREFIX);

    /** Local name of the XSI type. */
    public static final String TYPE_LOCAL_NAME = "RequestedAttributeExtensionType";

    /** QName of the XSI type. */
    public static final QName TYPE_NAME = new QName(UApproveJPMetadata.NAMESPACE, TYPE_LOCAL_NAME,
            UApproveJPMetadata.PREFIX);

    /** Name of the FriendlyName attribute. */
    public static final String FRIENDLY_NAME_ATTRIB_NAME = "FriendlyName";

    /**
     * Get the friendly name of this attribute.
     * 
     * @return the friendly name of this attribute
     */
    public String getFriendlyName();

    /**
     * Set the friendly name of this attribute.
     * 
     * @param friendlyName the friendly name of this attribute
     */
    public void setFriendlyName(String friendlyName);

    /**
     * Gets the list of descriptions for this.
     * 
     * @return the list of descriptions for this.
     */
    public List<Description> getDescriptions();

}
