/*
 * Copyright (c) 2016, National Institute of Informatics
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.gakunin.idp.saml.xmlobject.impl;

import javax.annotation.concurrent.ThreadSafe;

import jp.gakunin.idp.saml.xmlobject.Description;
import jp.gakunin.idp.saml.xmlobject.RequestedAttributeExtension;

import org.opensaml.saml.saml2.core.impl.AttributeUnmarshaller;
import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.w3c.dom.Attr;

/**
 * A thread-safe Unmarshaller for {@link jp.gakunin.idp.saml.xmlobject.RequestedAttributeExtension} objects.
 */
@ThreadSafe
public class RequestedAttributeExtensionUnmarshaller extends AttributeUnmarshaller {

    /** {@inheritDoc} */
    protected void processChildElement(final XMLObject parentSAMLObject, final XMLObject childSAMLObject)
            throws UnmarshallingException {
        final RequestedAttributeExtension requestedAttributeExtension = (RequestedAttributeExtension) parentSAMLObject;

        if (childSAMLObject instanceof Description) {
            requestedAttributeExtension.getDescriptions().add((Description) childSAMLObject);
        } else {
            super.processChildElement(parentSAMLObject, childSAMLObject);
        }
    }

    /** {@inheritDoc} */
    protected void processAttribute(final XMLObject samlObject, final Attr attribute) throws UnmarshallingException {
        final RequestedAttributeExtension requestedAttributeExtension = (RequestedAttributeExtension) samlObject;

        if (attribute.getLocalName().equals(RequestedAttributeExtension.FRIENDLY_NAME_ATTRIB_NAME)) {
            requestedAttributeExtension.setFriendlyName(attribute.getValue());
        } else {
            super.processAttribute(samlObject, attribute);
        }
    }

}
